%%%%%%%%%%%%%%%%%
%
% title.tex
%
%%%%%%%%%%%%%%%%
\def\Lrp#1{\centerbar{\liftpause{#1}}}
\normalmusicsize%
\tracingstats=2\relax
\hsize=266pt
\vsize=740pt
\def\nbinstruments{1}
\setstaffs11
\setclef10
\setname1{ }
\generalsignature{ 0}%
\parindent 0pt
\elemskip1pt\afterruleskip1.000pt\beforeruleskip0pt\relax
\stafftopmarg0pt\staffbotmarg5\Interligne\interstaff{10}\relax
\nostartrule
\Largemusicsize%
\startpiece\addspace\afterruleskip%
\znotes\zcharnote{16}{\titles{2.0}{}{0}{}{0}{}{0}}\en%
% bar  1
\def\Notes{\vnotes1.41\elemskip}%
\def\NOtes{\vnotes2.00\elemskip}%
\Notes\ibbu1{'a}0\qb1c\qs\qb1{`g}\tbu1\qb1g\en%
\NOtes\cchar{-6}{\ppff{sf}}\ibu1{'a}0\islurd8a\bigfl a\qb1a\tslur8{`g}%
\tbu1\qb1g\ds\cchar{-6}{\ppff{sf}}\upz{'b}\cl b\en%
% bar  2
\xbar
\NOtes\cchar{-6}{\ppff{sf}}\upz{'c}\cl c\en%
\Endpiece
